/*******************************************************************************
 * writebyte.c
 * Writes a byte to an address on a device connected to the parallel port
 * Uses an EPP-like protocol on a bidirectional parallel port
 *
 * July 14, 2005
 *
 * Michael Siegenthaler
 * www.msigi.net
 *
 ******************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "eppmanual.h"

void print_error(char* errmsg);

/*******************************************************************************
 * Main function
 ******************************************************************************/
int main(int argc, char **argv) {                    

  // Variable declarations
  int addr, data;

  // Check input
  if (argc!=3)
    print_error("Wrong number of arguments");

  if (sscanf(argv[1],"%i",&addr)!=1)
    print_error("Invalid address");

  if (sscanf(argv[2],"%i",&data)!=1)
    print_error("Invalid data");

  if ((addr<0) || (addr>255))
    print_error("Invalid address");

  if ((data<0) || (data>255))
    print_error("Invalid data");

  // Make sure we have permission to use the parallel port
  if (open_port())
    print_error("Cannot open parallel port");

  // Write to the port
  if (write_dev(addr, data)) print_error("Write failed");

  // Finished
  return 0;

}

/*******************************************************************************
 * Error routine
 * Prints an error message and syntax information
 * Parameters: option error message
 * Exits as a failure
 ******************************************************************************/
void print_error(char* errmsg) {

  if (errmsg) {
    fprintf(stderr,"ERROR: %s\n",errmsg);
  }
  fprintf(stderr,"Syntax: writebyte <address> <data>\n");
  fprintf(stderr,"<address> and <data> are each a decimal value between 0 and 255\n");
  exit(1);

}
